Struct frame::arithmetic::per_things::PerU16
pub struct PerU16(_);Expand description
A fixed point representation of a number in the range [0, 1].
Parts per 65535
Implementations
impl PerU16
impl PerU16
pub const fn from_parts(parts: u16) -> PerU16
pub const fn from_parts(parts: u16) -> PerU16
From an explicitly defined number of parts per maximum of the type.
pub const fn from_percent(x: u16) -> PerU16
pub const fn from_percent(x: u16) -> PerU16
Converts a percent into Self. Equal to x / 100.
This can be created at compile time.
pub const fn one() -> PerU16
pub const fn one() -> PerU16
See PerThing::one
pub fn is_one(&self) -> bool
pub fn is_one(&self) -> bool
See PerThing::is_one.
pub const fn zero() -> PerU16
pub const fn zero() -> PerU16
See PerThing::zero.
pub fn is_zero(&self) -> bool
pub fn is_zero(&self) -> bool
See PerThing::is_zero.
pub const fn deconstruct(self) -> u16
pub const fn deconstruct(self) -> u16
pub fn square(self) -> PerU16
pub fn square(self) -> PerU16
See PerThing::square.
pub fn from_float(x: f64) -> PerU16
pub fn from_float(x: f64) -> PerU16
See PerThing::from_float.
pub fn from_rational_approximation<N>(p: N, q: N) -> PerU16where
N: RationalArg + TryInto<u16> + TryInto<u32>,
u16: Into<N>,
👎Deprecated: Use PerThing::from_rational instead
pub fn from_rational_approximation<N>(p: N, q: N) -> PerU16where N: RationalArg + TryInto<u16> + TryInto<u32>, u16: Into<N>,
PerThing::from_rational insteadpub fn from_rational<N>(p: N, q: N) -> PerU16where
N: RationalArg + TryInto<u16> + TryInto<u32>,
u16: Into<N>,
pub fn from_rational<N>(p: N, q: N) -> PerU16where N: RationalArg + TryInto<u16> + TryInto<u32>, u16: Into<N>,
pub fn mul_floor<N>(self, b: N) -> Nwhere
N: MultiplyArg + UniqueSaturatedInto<u16>,
u16: Into<N>,
pub fn mul_floor<N>(self, b: N) -> Nwhere N: MultiplyArg + UniqueSaturatedInto<u16>, u16: Into<N>,
See PerThing::mul_floor.
pub fn mul_ceil<N>(self, b: N) -> Nwhere
N: MultiplyArg + UniqueSaturatedInto<u16>,
u16: Into<N>,
pub fn mul_ceil<N>(self, b: N) -> Nwhere N: MultiplyArg + UniqueSaturatedInto<u16>, u16: Into<N>,
See PerThing::mul_ceil.
pub fn saturating_reciprocal_mul<N>(self, b: N) -> Nwhere
N: ReciprocalArg + UniqueSaturatedInto<u16>,
u16: Into<N>,
pub fn saturating_reciprocal_mul<N>(self, b: N) -> Nwhere N: ReciprocalArg + UniqueSaturatedInto<u16>, u16: Into<N>,
pub fn saturating_reciprocal_mul_floor<N>(self, b: N) -> Nwhere
N: ReciprocalArg + UniqueSaturatedInto<u16>,
u16: Into<N>,
pub fn saturating_reciprocal_mul_floor<N>(self, b: N) -> Nwhere N: ReciprocalArg + UniqueSaturatedInto<u16>, u16: Into<N>,
pub fn saturating_reciprocal_mul_ceil<N>(self, b: N) -> Nwhere
N: ReciprocalArg + UniqueSaturatedInto<u16>,
u16: Into<N>,
pub fn saturating_reciprocal_mul_ceil<N>(self, b: N) -> Nwhere N: ReciprocalArg + UniqueSaturatedInto<u16>, u16: Into<N>,
pub fn saturating_div(self, rhs: PerU16, r: Rounding) -> PerU16
pub fn saturating_div(self, rhs: PerU16, r: Rounding) -> PerU16
Saturating division. Compute self / rhs, saturating at one if rhs < self.
The rounding method must be specified. e.g.:
let pc = |x| Percent::from_percent(x);
assert_eq!(
pc(2).saturating_div(pc(3), Down),
pc(66),
);
assert_eq!(
pc(1).saturating_div(pc(3), NearestPrefUp),
pc(33),
);
assert_eq!(
pc(2).saturating_div(pc(3), NearestPrefDown),
pc(67),
);
assert_eq!(
pc(1).saturating_div(pc(3), Up),
pc(34),
);impl PerU16
impl PerU16
pub const fn from_perthousand(x: u16) -> PerU16
pub const fn from_perthousand(x: u16) -> PerU16
Converts a percent into Self. Equal to x / 1000.
This can be created at compile time.